@@ -1,12 +1,12 @@
 import asyncio
 import json
 import os
-import subprocess
 import sys
+import traceback
 import webbrowser
 from contextlib import suppress
 from pathlib import Path
-from typing import AsyncGenerator, Optional, Dict, Any, List
+from typing import AsyncIterator, Optional, Dict, Any, List
 
 import pytest
 from aiohttp.web_request import Request
@@ -17,12 +17,23 @@ from bantam.api import AsyncLineIterator, RestMethod
 from bantam.http import WebApplication
 
 
-@web_api(content_type='text/plain', method=RestMethod.POST)
+__all__ = ['ClassRestExample']
+
+
 class ClassRestExample:
+    """
+    HTTP resource for testing class with instance methods
+    """
 
     def __init__(self, val: int):
+        """
+        Create a session-level object
+
+        :param val: some dummy value
+        """
         self._value = val
 
+    @web_api(content_type='text/plain', method=RestMethod.POST)
     async def echo(self, param1: int, param2: bool, param3: float, param4: Optional[str] = "text") -> str:
         """
         Some sort of doc
@@ -35,73 +46,11 @@ class ClassRestExample:
         return f"called basic post operation on instance {self._value}: {param1} {param2} {param3} {param4}"
 
 
-@web_api(content_type='text/plain', method=RestMethod.POST)
-class ClassRestStaticExample:
-
-    @staticmethod
-    async def api_post_basic(param1: int, param2: bool, param3: float, param4: Optional[str] = "text") -> str:
-        """
-        Some sort of doc
-        :param param1:
-        :param param2:
-        :param param3:
-        :param param4:
-        :return: stream of int
-        """
-        return "called basic post operation"
-
-    @staticmethod
-    async def api_post_stream(param1: int, param2: bool, param3: float, param4: str) -> AsyncGenerator[None, int]:
-        """
-        Some sort of doc
-        :param param1:
-        :param param2:
-        :param param3:
-        :param param4:
-        :return: stream of int
-        """
-        for index in range(10):
-            yield index
-            await asyncio.sleep(0.02)
-
-    @staticmethod
-    async def api_post_streamed_req_and_resp(param1: int, param2: bool, param3: float, param4: AsyncLineIterator)\
-            -> AsyncGenerator[None, str]:
-        """
-        Some sort of doc
-        :param param1:
-        :param param2:
-        :param param3:
-        :param param4:
-        :return: stream of int
-        """
-        async for line in param4:
-            yield f"ECHO: {line}"
-            await asyncio.sleep(0.02)
-
-    @staticmethod
-    async def api_post_stream_text(param1: int, param2: bool, param3: float, param4: Optional[str] = None) -> AsyncGenerator[None, str]:
-        """
-        Some sort of doc
-        :param param1:
-        :param param2:
-        :param param3:
-        :param param4:
-        :return: stream of int
-        """
-        for index in range(10):
-            yield f"COUNT: {index}"
-            await asyncio.sleep(0.02)
-        yield "DONE"
-
-    @staticmethod
-    async def publish_result(result: str) -> None:
-        await RestAPIExample.result_queue.put(result)
-
-
 class RestAPIExample:
-
-    result_queue : Optional[asyncio.Queue] = None
+    """
+    HTTP resource for testing ReST examples, with all static methods
+    """
+    result_queue: Optional[asyncio.Queue] = None
 
     @web_api(content_type='text/plain', method=RestMethod.GET)
     @staticmethod
@@ -118,7 +67,7 @@ class RestAPIExample:
 
     @web_api(content_type='text/json', method=RestMethod.GET)
     @staticmethod
-    async def api_get_stream(param1: int, param2: bool, param3: float, param4: Optional[str] = None) -> AsyncGenerator[None, int]:
+    async def api_get_stream(param1: int, param2: bool, param3: float, param4: Optional[str] = None) -> AsyncIterator[int]:
         """
         Some sort of doc
         :param param1:
@@ -134,7 +83,7 @@ class RestAPIExample:
     @web_api(content_type='text/json', method=RestMethod.GET)
     @staticmethod
     async def api_get_stream_bytes(param1: int, param2: bool, param3: float, param4: Optional[str] = None,
-                                  param5: Optional[List[int]] = None) -> AsyncGenerator[None, bytes]:
+                                  param5: Optional[List[int]] = None) -> AsyncIterator[bytes]:
         """
         Some sort of doc
         :param param1:
@@ -163,7 +112,7 @@ class RestAPIExample:
 
     @web_api(content_type='text/json', method=RestMethod.POST)
     @staticmethod
-    async def api_post_stream(param1: int, param2: bool, param3: float, param4: str) -> AsyncGenerator[None, int]:
+    async def api_post_stream(param1: int, param2: bool, param3: float, param4: str) -> AsyncIterator[int]:
         """
         Some sort of doc
         :param param1:
@@ -179,7 +128,7 @@ class RestAPIExample:
     @web_api(content_type='text/plain', method=RestMethod.POST)
     @staticmethod
     async def api_post_streamed_req_and_resp(param1: int, param2: bool, param3: float, param4: AsyncLineIterator)\
-            -> AsyncGenerator[None, str]:
+            -> AsyncIterator[str]:
         """
         Some sort of doc
         :param param1:
@@ -194,7 +143,7 @@ class RestAPIExample:
 
     @web_api(content_type='text/json', method=RestMethod.POST)
     @staticmethod
-    async def api_post_stream_text(param1: int, param2: bool, param3: float, param4: Optional[str] = None) -> AsyncGenerator[None, str]:
+    async def api_post_stream_text(param1: int, param2: bool, param3: float, param4: Optional[str] = None) -> AsyncIterator[str]:
         """
         Some sort of doc
         :param param1:
@@ -235,7 +184,6 @@ class TestJavascriptGenerator:
         async def launch_browser():
             await asyncio.sleep(2.0)
             browser = None
-            default = False
             try:
                 browser = webbrowser.get("chrome")
             except Exception:
@@ -243,35 +191,21 @@ class TestJavascriptGenerator:
                     browser = webbrowser.get("google-chrome")
                 if not browser:
                     browser = webbrowser.get()
-                    default = True
-            if not browser:
-                raise Exception("No browser found")
-            flags = ["--new-window"] if browser and not default else []
-            if not browser:
-                with suppress(Exception):
-                    browser = webbrowser.get("firefox")
-                    flags = ["-new-instance"]
             if not browser:
                 os.write(sys.stderr.fileno(),
                          b"UNABLE TO GET BROWSER SUPPORINT HEADLESS CONFIGURATION. DEFAULTING TO NON_HEADLESSS")
                 browser = webbrowser.get()
             browser.open("http://localhost:8080/static/index_async.html")
-            #cmdline = [browser.name] + flags + ["http://localhost:8080/static/index_async.html"]
-            #process = subprocess.Popen(cmdline)
             result = await RestAPIExample.result_queue.get()
             await asyncio.sleep(2.0)
             await app.shutdown()
-            # if process.returncode != None:
-            #    raise Exception("Browser died!")
-            # process.kill()
             return result
 
         try:
             completed, _ = await asyncio.wait([app.start(), launch_browser()], timeout=100, return_when=asyncio.FIRST_COMPLETED)
             results = [c.result() for c in completed if c is not None]
         except Exception as e:
-            assert False, f"Exception processing javascript results: {e}"
-
+            assert False, f"Exception processing javascript results: {traceback.format_exc()}"
         if any([isinstance(r, Exception) for r in results]):
             assert False, "At least one javascript test failed. See browser window for details"
         assert results[0] == "PASSED", \
